<?php

namespace AbonnementApiV6\StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for getAbonnementsoortInfoRequest StructType
 * Meta information extracted from the WSDL
 * - documentation: Ophalen van de gegevens van een of meerdere abonnementsoorten. Hierbij kan gezocht worden op basis van de abonnementsoortcode, de uitgavecode en op inactieve abonnementsoorten.
 * @subpackage Structs
 * @date 20240419 package
 */
class GetAbonnementsoortInfoRequest extends AbstractStructBase
{
    /**
     * The requestTag
     * Meta information extracted from the WSDL
     * - documentation: Vrij veld voor aanroepende partij. De inhoud van dit veld wordt altijd identiek teruggestuurd.
     * - base: xsd:string
     * - maxLength: 4000
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * @var string
     */
    public $requestTag;
    /**
     * The abonnementsoortCode
     * Meta information extracted from the WSDL
     * - documentation: Code van de abonnementsoort waarvan de informatie wordt opgevraagd. Indien leeg wordt van alle abonnementsoorten de gegevens opgehaald.
     * - base: xsd:string
     * - maxLength: 30
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * @var string
     */
    public $abonnementsoortCode;
    /**
     * The uitgaveCode
     * Meta information extracted from the WSDL
     * - documentation: Code van de uitgave. Indien abonnementsoortcode leeg is, worden alleen abonnementsoorten van de opgegeven uitgave opgehaald. Indien leeg, alle abonnementsoorten.
     * - base: xsd:string
     * - maxLength: 12
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * @var string
     */
    public $uitgaveCode;
    /**
     * The landCode
     * Meta information extracted from the WSDL
     * - documentation: Landcode. Wordt gebruikt om landspecifieke prijs van de abonnementsoort te te bepalen.
     * - base: xsd:string
     * - maxLength: 3
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * @var string
     */
    public $landCode;
    /**
     * The relNo
     * Meta information extracted from the WSDL
     * - documentation: Relatienummer. Wordt gebruikt om relatiespecifieke prijs van de abonnementsoort te bepalen.
     * - base: xsd:integer
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * - totalDigits: 15
     * @var int
     */
    public $relNo;
    /**
     * The aantalExemplaren
     * Meta information extracted from the WSDL
     * - documentation: Aantal exemplaren. wordt gebruikt om prijs van de abonnementsoort te te bepalen voor het specifieke aantal exemplaren.
     * - base: xsd:integer
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * - totalDigits: 15
     * @var int
     */
    public $aantalExemplaren;
    /**
     * The inclusiefInactieve
     * Meta information extracted from the WSDL
     * - documentation: Indicatie of inactieve abonnementsoorten teruggegeven moet worden. false (Default) = Alleen actieve. true = Inclusief inactieve.
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * @var bool
     */
    public $inclusiefInactieve;
    /**
     * Constructor method for getAbonnementsoortInfoRequest
     * @uses GetAbonnementsoortInfoRequest::setRequestTag()
     * @uses GetAbonnementsoortInfoRequest::setAbonnementsoortCode()
     * @uses GetAbonnementsoortInfoRequest::setUitgaveCode()
     * @uses GetAbonnementsoortInfoRequest::setLandCode()
     * @uses GetAbonnementsoortInfoRequest::setRelNo()
     * @uses GetAbonnementsoortInfoRequest::setAantalExemplaren()
     * @uses GetAbonnementsoortInfoRequest::setInclusiefInactieve()
     * @param string $requestTag
     * @param string $abonnementsoortCode
     * @param string $uitgaveCode
     * @param string $landCode
     * @param int $relNo
     * @param int $aantalExemplaren
     * @param bool $inclusiefInactieve
     */
    public function __construct($requestTag = null, $abonnementsoortCode = null, $uitgaveCode = null, $landCode = null, $relNo = null, $aantalExemplaren = null, $inclusiefInactieve = null)
    {
        $this
            ->setRequestTag($requestTag)
            ->setAbonnementsoortCode($abonnementsoortCode)
            ->setUitgaveCode($uitgaveCode)
            ->setLandCode($landCode)
            ->setRelNo($relNo)
            ->setAantalExemplaren($aantalExemplaren)
            ->setInclusiefInactieve($inclusiefInactieve);
    }
    /**
     * Get requestTag value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return string|null
     */
    public function getRequestTag()
    {
        return isset($this->requestTag) ? $this->requestTag : null;
    }
    /**
     * Set requestTag value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param string $requestTag
     * @return \AbonnementApiV6\StructType\GetAbonnementsoortInfoRequest
     */
    public function setRequestTag($requestTag = null)
    {
        // validation for constraint: string
        if (!is_null($requestTag) && !is_string($requestTag)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($requestTag, true), gettype($requestTag)), __LINE__);
        }
        // validation for constraint: maxLength(4000)
        if (!is_null($requestTag) && mb_strlen($requestTag) > 4000) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 4000', mb_strlen($requestTag)), __LINE__);
        }
        if (is_null($requestTag) || (is_array($requestTag) && empty($requestTag))) {
            unset($this->requestTag);
        } else {
            $this->requestTag = $requestTag;
        }
        return $this;
    }
    /**
     * Get abonnementsoortCode value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return string|null
     */
    public function getAbonnementsoortCode()
    {
        return isset($this->abonnementsoortCode) ? $this->abonnementsoortCode : null;
    }
    /**
     * Set abonnementsoortCode value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param string $abonnementsoortCode
     * @return \AbonnementApiV6\StructType\GetAbonnementsoortInfoRequest
     */
    public function setAbonnementsoortCode($abonnementsoortCode = null)
    {
        // validation for constraint: string
        if (!is_null($abonnementsoortCode) && !is_string($abonnementsoortCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($abonnementsoortCode, true), gettype($abonnementsoortCode)), __LINE__);
        }
        // validation for constraint: maxLength(30)
        if (!is_null($abonnementsoortCode) && mb_strlen($abonnementsoortCode) > 30) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 30', mb_strlen($abonnementsoortCode)), __LINE__);
        }
        if (is_null($abonnementsoortCode) || (is_array($abonnementsoortCode) && empty($abonnementsoortCode))) {
            unset($this->abonnementsoortCode);
        } else {
            $this->abonnementsoortCode = $abonnementsoortCode;
        }
        return $this;
    }
    /**
     * Get uitgaveCode value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return string|null
     */
    public function getUitgaveCode()
    {
        return isset($this->uitgaveCode) ? $this->uitgaveCode : null;
    }
    /**
     * Set uitgaveCode value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param string $uitgaveCode
     * @return \AbonnementApiV6\StructType\GetAbonnementsoortInfoRequest
     */
    public function setUitgaveCode($uitgaveCode = null)
    {
        // validation for constraint: string
        if (!is_null($uitgaveCode) && !is_string($uitgaveCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($uitgaveCode, true), gettype($uitgaveCode)), __LINE__);
        }
        // validation for constraint: maxLength(12)
        if (!is_null($uitgaveCode) && mb_strlen($uitgaveCode) > 12) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 12', mb_strlen($uitgaveCode)), __LINE__);
        }
        if (is_null($uitgaveCode) || (is_array($uitgaveCode) && empty($uitgaveCode))) {
            unset($this->uitgaveCode);
        } else {
            $this->uitgaveCode = $uitgaveCode;
        }
        return $this;
    }
    /**
     * Get landCode value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return string|null
     */
    public function getLandCode()
    {
        return isset($this->landCode) ? $this->landCode : null;
    }
    /**
     * Set landCode value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param string $landCode
     * @return \AbonnementApiV6\StructType\GetAbonnementsoortInfoRequest
     */
    public function setLandCode($landCode = null)
    {
        // validation for constraint: string
        if (!is_null($landCode) && !is_string($landCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($landCode, true), gettype($landCode)), __LINE__);
        }
        // validation for constraint: maxLength(3)
        if (!is_null($landCode) && mb_strlen($landCode) > 3) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 3', mb_strlen($landCode)), __LINE__);
        }
        if (is_null($landCode) || (is_array($landCode) && empty($landCode))) {
            unset($this->landCode);
        } else {
            $this->landCode = $landCode;
        }
        return $this;
    }
    /**
     * Get relNo value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return int|null
     */
    public function getRelNo()
    {
        return isset($this->relNo) ? $this->relNo : null;
    }
    /**
     * Set relNo value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param int $relNo
     * @return \AbonnementApiV6\StructType\GetAbonnementsoortInfoRequest
     */
    public function setRelNo($relNo = null)
    {
        // validation for constraint: int
        if (!is_null($relNo) && !(is_int($relNo) || ctype_digit($relNo))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($relNo, true), gettype($relNo)), __LINE__);
        }
        // validation for constraint: totalDigits(15)
        if (!is_null($relNo) && mb_strlen(preg_replace('/(\D)/', '', $relNo)) > 15) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, the value must use at most 15 digits, "%d" given', var_export($relNo, true), mb_strlen(preg_replace('/(\D)/', '', $relNo))), __LINE__);
        }
        if (is_null($relNo) || (is_array($relNo) && empty($relNo))) {
            unset($this->relNo);
        } else {
            $this->relNo = $relNo;
        }
        return $this;
    }
    /**
     * Get aantalExemplaren value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return int|null
     */
    public function getAantalExemplaren()
    {
        return isset($this->aantalExemplaren) ? $this->aantalExemplaren : null;
    }
    /**
     * Set aantalExemplaren value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param int $aantalExemplaren
     * @return \AbonnementApiV6\StructType\GetAbonnementsoortInfoRequest
     */
    public function setAantalExemplaren($aantalExemplaren = null)
    {
        // validation for constraint: int
        if (!is_null($aantalExemplaren) && !(is_int($aantalExemplaren) || ctype_digit($aantalExemplaren))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($aantalExemplaren, true), gettype($aantalExemplaren)), __LINE__);
        }
        // validation for constraint: totalDigits(15)
        if (!is_null($aantalExemplaren) && mb_strlen(preg_replace('/(\D)/', '', $aantalExemplaren)) > 15) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, the value must use at most 15 digits, "%d" given', var_export($aantalExemplaren, true), mb_strlen(preg_replace('/(\D)/', '', $aantalExemplaren))), __LINE__);
        }
        if (is_null($aantalExemplaren) || (is_array($aantalExemplaren) && empty($aantalExemplaren))) {
            unset($this->aantalExemplaren);
        } else {
            $this->aantalExemplaren = $aantalExemplaren;
        }
        return $this;
    }
    /**
     * Get inclusiefInactieve value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return bool|null
     */
    public function getInclusiefInactieve()
    {
        return isset($this->inclusiefInactieve) ? $this->inclusiefInactieve : null;
    }
    /**
     * Set inclusiefInactieve value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param bool $inclusiefInactieve
     * @return \AbonnementApiV6\StructType\GetAbonnementsoortInfoRequest
     */
    public function setInclusiefInactieve($inclusiefInactieve = null)
    {
        // validation for constraint: boolean
        if (!is_null($inclusiefInactieve) && !is_bool($inclusiefInactieve)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a bool, %s given', var_export($inclusiefInactieve, true), gettype($inclusiefInactieve)), __LINE__);
        }
        if (is_null($inclusiefInactieve) || (is_array($inclusiefInactieve) && empty($inclusiefInactieve))) {
            unset($this->inclusiefInactieve);
        } else {
            $this->inclusiefInactieve = $inclusiefInactieve;
        }
        return $this;
    }
}
